@@ -47,9 +47,9 @@ MclustDA <- function(data, class, G = NULL, modelNames = NULL,
   if(!is.list(modelNames))
     { modelNames <- rep(list(modelNames), ncl) }
   #
-  hcUse <- mclust.options("hcUse")
-  mclust.options("hcUse" = "VARS")
-  on.exit(mclust.options("hcUse" = hcUse))
+  # hcUse <- mclust.options("hcUse")
+  # mclust.options("hcUse" = "VARS")
+  # on.exit(mclust.options("hcUse" = hcUse))
   #
   if(modelType == "EDDA")
   { 
@@ -85,7 +85,7 @@ MclustDA <- function(data, class, G = NULL, modelNames = NULL,
     bic <- max(BIC, na.rm = TRUE)
     loglik <- Model$loglik
     df <- (2*loglik - bic)/log(Model$n)
-    # there are (nclass-1) more df than real needed
+    # there are (nclass-1) more df than really needed
     # equal to logLik(object) but faster
     Model <- c(Model, list("BIC" = BIC))
     Models <- rep(list(Model), ncl)
@@ -394,7 +394,8 @@ predict.MclustDA <- function(object, newdata, prop = object$prop, ...)
   
   models <- object$models
   nclass <- length(models)
-  classNames <- levels(object$class)
+  classNames <- if(is.null(object$class)) names(models)
+                else                      levels(object$class)
   n <- sapply(1:nclass, function(i) models[[i]]$n)
   if(missing(newdata))
     { newdata <- object$data }
@@ -718,7 +719,7 @@ plot.MclustDA <- function(x, what = c("scatterplot", "classification", "train&te
     if(d == 2)
     { 
       coordProj(Data, dimens = dimens[1:2], what = "classification",
-                classification = cl, CEX = 0.8,
+                classification = cl, cex = 0.8,
                 symbols = c(19,3), colors = c("grey80", "grey20"),
                 main = FALSE, ...)
       if(!is.null(main))
@@ -1129,7 +1130,8 @@ classPriorProbs <- function(object, newdata = object$data,
   p <- colMeans(z)
   p0 <- p+1
   it <- 0
-  while(max(abs(p-p0)/abs(p)) > eps & it < itmax)
+  # while(max(abs(p-p0)/abs(p)) > eps & it < itmax)
+  while(any(abs(p-p0) > eps*(1+abs(p))) & it < itmax)
   {
     it <- it+1
     p0 <- p
